
Unauthorized credential changes
-------

**Description:**

An application which offers a user login functionality, usually has an administration page 
where his user-data can be modified. When the user wants to change this data he should 
specify his current password.


**Solution:**

When changing user credentials or email address the user must always enter a valid 
password in order to implement the changes.

	